r21017 by craig -

scribus-commit scribus-commit at lists.scribus.net
Wed Feb 17 21:59:37 UTC 2016


Author: craig
Date: Wed Feb 17 21:59:37 2016
New Revision: 21017

URL: http://scribus.net/websvn/listing.php?repname=Scribus&sc=1&rev=21017
Log:
#13647: commit successful diff application for speelung errors

Modified:
    trunk/Scribus/scribus/actionmanager.cpp
    trunk/Scribus/scribus/appmodehelper.cpp
    trunk/Scribus/scribus/canvasmode.cpp
    trunk/Scribus/scribus/canvasmode.h
    trunk/Scribus/scribus/canvasmode_rotate.cpp
    trunk/Scribus/scribus/collapsedtablepainter.cpp
    trunk/Scribus/scribus/colorblind.h
    trunk/Scribus/scribus/fileloader.cpp
    trunk/Scribus/scribus/fonts/cff.cpp
    trunk/Scribus/scribus/fonts/ftface.cpp
    trunk/Scribus/scribus/fonts/scface.cpp
    trunk/Scribus/scribus/fonts/scface_ps.h
    trunk/Scribus/scribus/guidesmodel.h
    trunk/Scribus/scribus/hyphenator.h
    trunk/Scribus/scribus/observable.h
    trunk/Scribus/scribus/pageitem.h
    trunk/Scribus/scribus/pageitem_latexframe.h
    trunk/Scribus/scribus/pageitem_textframe.cpp
    trunk/Scribus/scribus/pdflib_core.h
    trunk/Scribus/scribus/prefsmanager.cpp
    trunk/Scribus/scribus/qtiocompressor.cpp
    trunk/Scribus/scribus/sampleitem.h
    trunk/Scribus/scribus/scribus.cpp
    trunk/Scribus/scribus/scribus.h
    trunk/Scribus/scribus/scribusdoc.cpp
    trunk/Scribus/scribus/scribusdoc.h
    trunk/Scribus/scribus/selection.h
    trunk/Scribus/scribus/tableborder.h
    trunk/Scribus/scribus/tocgenerator.cpp
    trunk/Scribus/scribus/transaction.h
    trunk/Scribus/scribus/ui/aboutplugins.cpp
    trunk/Scribus/scribus/ui/helpbrowser.cpp
    trunk/Scribus/scribus/ui/helpbrowser.h
    trunk/Scribus/scribus/ui/pageitemattributes.cpp
    trunk/Scribus/scribus/ui/pageitemsetterbase.h
    trunk/Scribus/scribus/ui/printdialog.cpp
    trunk/Scribus/scribus/ui/propertiespalette.cpp
    trunk/Scribus/scribus/ui/resourcemanager.cpp
    trunk/Scribus/scribus/ui/scrpalettebase.h
    trunk/Scribus/scribus/ui/scrspinbox.cpp
    trunk/Scribus/scribus/ui/smlinestyle.cpp
    trunk/Scribus/scribus/ui/storyeditor.cpp
    trunk/Scribus/scribus/ui/stylemanager.cpp
    trunk/Scribus/scribus/ui/tabruler.h
    trunk/Scribus/scribus/ui/unicodesearch.h
    trunk/Scribus/scribus/undogui.h
    trunk/Scribus/scribus/units.cpp
    trunk/Scribus/scribus/util_printer.cpp

Modified: trunk/Scribus/scribus/actionmanager.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/actionmanager.cpp
==============================================================================
--- trunk/Scribus/scribus/actionmanager.cpp	(original)
+++ trunk/Scribus/scribus/actionmanager.cpp	Wed Feb 17 21:59:37 2016
@@ -2519,7 +2519,7 @@
 
 void ActionManager::languageChangeActions()
 {
-	//Here we mangle the URL based on the current GUI language, returning English if we dont get one of these hard coded options.
+	//Here we mangle the URL based on the current GUI language, returning English if we don't get one of these hard coded options.
 	//CB TODO make more flexible one day.
 	QString language="EN";
 	QString langpref(ScCore->getGuiLanguage().left(2));

Modified: trunk/Scribus/scribus/appmodehelper.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/appmodehelper.cpp
==============================================================================
--- trunk/Scribus/scribus/appmodehelper.cpp	(original)
+++ trunk/Scribus/scribus/appmodehelper.cpp	Wed Feb 17 21:59:37 2016
@@ -91,7 +91,7 @@
 		return;
 	}
 
-	//disconnect the tools actions so we dont fire them off
+	//disconnect the tools actions so we don't fire them off
 	a_actMgr->disconnectModeActions();
 	setModeActionsPerMode(newMode);
 
@@ -101,7 +101,7 @@
 	if (!doc->m_Selection->isEmpty())
 		currItem = doc->m_Selection->itemAt(0);
 
-	//Ugly hack but I have absolutly no idea about how to do this in another way
+	//Ugly hack but I have absolutely no idea about how to do this in another way
 	if (UndoManager::undoEnabled() && currItem && oldMode != newMode && (newMode == modeEditMeshPatch || oldMode == modeEditMeshPatch ||
 																		newMode == modeEditMeshGradient || oldMode == modeEditMeshGradient ||
 																		newMode == modeEditGradientVectors || oldMode == modeEditGradientVectors ||

Modified: trunk/Scribus/scribus/canvasmode.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/canvasmode.cpp
==============================================================================
--- trunk/Scribus/scribus/canvasmode.cpp	(original)
+++ trunk/Scribus/scribus/canvasmode.cpp	Wed Feb 17 21:59:37 2016
@@ -1402,7 +1402,7 @@
 			bool resizingsmaller=(resizing && (buttonModifiers & Qt::ShiftModifier));
 			double resizeBy=1.0;
 			//CB with control locked out due to the requirement of moveby of 0.01, we cannot support
-			//resizeby 10 units unless we move to supporting modifier keys that most people dont have.
+			//resizeby 10 units unless we move to supporting modifier keys that most people don't have.
 			//if (buttonModifiers & Qt::ControlModifier)
 			//	resizeBy*=10.0;
 			resizeBy/=m_doc->unitRatio();

Modified: trunk/Scribus/scribus/canvasmode.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/canvasmode.h
==============================================================================
--- trunk/Scribus/scribus/canvasmode.h	(original)
+++ trunk/Scribus/scribus/canvasmode.h	Wed Feb 17 21:59:37 2016
@@ -110,7 +110,7 @@
 	virtual bool handleKeyEvents() { return false; }
 
 	/**
-		Sets appropiate values for this canvas mode
+		Sets appropriate values for this canvas mode
 	 */
 	virtual void updateViewMode(CanvasViewMode* viewmode);
 	
@@ -141,7 +141,7 @@
 	QCursor modeCursor();
 	void setModeCursor();
 	
-	/** main canvas modes dont have a delegate */
+	/** main canvas modes don't have a delegate */
 	virtual CanvasMode* delegate() { return 0; }
 	ScribusView* view() const { return m_view; }
 	virtual ~CanvasMode();

Modified: trunk/Scribus/scribus/canvasmode_rotate.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/canvasmode_rotate.cpp
==============================================================================
--- trunk/Scribus/scribus/canvasmode_rotate.cpp	(original)
+++ trunk/Scribus/scribus/canvasmode_rotate.cpp	Wed Feb 17 21:59:37 2016
@@ -370,7 +370,7 @@
 	}
 	for (int i = 0; i < m_doc->m_Selection->count(); ++i)
 		m_doc->m_Selection->itemAt(i)->checkChanges(true);
-	//Make sure the Zoom spinbox and page selector dont have focus if we click on the canvas
+	//Make sure the Zoom spinbox and page selector don't have focus if we click on the canvas
 	m_view->m_ScMW->zoomSpinBox->clearFocus();
 	m_view->m_ScMW->pageSelector->clearFocus();
 }

Modified: trunk/Scribus/scribus/collapsedtablepainter.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/collapsedtablepainter.cpp
==============================================================================
--- trunk/Scribus/scribus/collapsedtablepainter.cpp	(original)
+++ trunk/Scribus/scribus/collapsedtablepainter.cpp	Wed Feb 17 21:59:37 2016
@@ -490,7 +490,7 @@
 	QPointF lineStart, lineEnd;
 	foreach (const TableBorderLine& line, border.borderLines())
 	{
-		// Adjust line start and ends by line width multipled by offset factors.
+		// Adjust line start and ends by line width multiplied by offset factors.
 		lineStart.setX(start.x() + line.width() * startOffsetFactors.x());
 		lineStart.setY(start.y() + line.width() * startOffsetFactors.y());
 		lineEnd.setX(end.x() + line.width() * endOffsetFactors.x());

Modified: trunk/Scribus/scribus/colorblind.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/colorblind.h
==============================================================================
--- trunk/Scribus/scribus/colorblind.h	(original)
+++ trunk/Scribus/scribus/colorblind.h	Wed Feb 17 21:59:37 2016
@@ -145,7 +145,7 @@
 	*/
 	void init();
 
-	/*! \brief This function performs initialisations that are dependant
+	/*! \brief This function performs initialisations that are dependent
 	on the type of color deficiency (see defectMode). */
 	void setupDefect();
 

Modified: trunk/Scribus/scribus/fileloader.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/fileloader.cpp
==============================================================================
--- trunk/Scribus/scribus/fileloader.cpp	(original)
+++ trunk/Scribus/scribus/fileloader.cpp	Wed Feb 17 21:59:37 2016
@@ -202,7 +202,7 @@
 		}
 	}
 	if (ret)
-		ret = postLoad(currDoc);  // FIXME: return false if user doesnt want to replace fonts??
+		ret = postLoad(currDoc);  // FIXME: return false if user doesn't want to replace fonts??
 
 	return ret;
 }

Modified: trunk/Scribus/scribus/fonts/cff.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/fonts/cff.cpp
==============================================================================
--- trunk/Scribus/scribus/fonts/cff.cpp	(original)
+++ trunk/Scribus/scribus/fonts/cff.cpp	Wed Feb 17 21:59:37 2016
@@ -975,7 +975,7 @@
 				break;
 			case cff_varnt_Delta:
 				result += "Delta";
-				/* fall thru */
+				/* fall through */
 			case cff_varnt_Array:
 				result += "[";
 				for (int i = 0; i < var.array.length(); ++i)

Modified: trunk/Scribus/scribus/fonts/ftface.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/fonts/ftface.cpp
==============================================================================
--- trunk/Scribus/scribus/fonts/ftface.cpp	(original)
+++ trunk/Scribus/scribus/fonts/ftface.cpp	Wed Feb 17 21:59:37 2016
@@ -30,7 +30,7 @@
    
    canRender(unicode) -> CharMap cache? -> loadChar/Glyph -> !broken
    Glyphs:  width    status
-            -1000    unkown
+            -1000    unknown
             -2000    broken
             >= 0     ok, outline valid
    CharMap:  unicode -> glyph index

Modified: trunk/Scribus/scribus/fonts/scface.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/fonts/scface.cpp
==============================================================================
--- trunk/Scribus/scribus/fonts/scface.cpp	(original)
+++ trunk/Scribus/scribus/fonts/scface.cpp	Wed Feb 17 21:59:37 2016
@@ -126,7 +126,7 @@
    
    canRender(unicode) -> CharMap cache? -> loadChar/Glyph -> !broken
    Glyphs:  width    status
-            -1000    unkown
+            -1000    unknown
             -2000    broken
             >= 0     ok, outline valid
    CharMap:  unicode -> glyph index

Modified: trunk/Scribus/scribus/fonts/scface_ps.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/fonts/scface_ps.h
==============================================================================
--- trunk/Scribus/scribus/fonts/scface_ps.h	(original)
+++ trunk/Scribus/scribus/fonts/scface_ps.h	Wed Feb 17 21:59:37 2016
@@ -57,7 +57,7 @@
 			{
 				// re-initialize: ScFaceData::load() just clears caches,
 				// FtFace::load() skips FT_New_Face if m_face is already defined.
-				// dont mind checking glyphs again for now (PS files have only 255 glyphs max, anyway)
+				// don't mind checking glyphs again for now (PS files have only 255 glyphs max, anyway)
 				FtFace::load();
 			}
 //			Ascent = tmp.setNum(face->ascender);

Modified: trunk/Scribus/scribus/guidesmodel.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/guidesmodel.h
==============================================================================
--- trunk/Scribus/scribus/guidesmodel.h	(original)
+++ trunk/Scribus/scribus/guidesmodel.h	Wed Feb 17 21:59:37 2016
@@ -56,7 +56,7 @@
 #endif
 
 	signals:
-		/*! \brief Signal emmitted when the user finish the editation of one value.
+		/*! \brief Signal emitted when the user finishes editing one value.
 		*/
 		void valueChanged();
 

Modified: trunk/Scribus/scribus/hyphenator.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/hyphenator.h
==============================================================================
--- trunk/Scribus/scribus/hyphenator.h	(original)
+++ trunk/Scribus/scribus/hyphenator.h	Wed Feb 17 21:59:37 2016
@@ -46,7 +46,7 @@
 	
 private:
 
-	/*! Embeded reference to the \see ScribusDoc filled by \a dok */
+	/*! Embedded reference to the \see ScribusDoc filled by \a dok */
 	ScribusDoc *m_doc;
 	/*! Reference to the hyphen dictionary structure. */
 	HyphenDict *m_hdict;
@@ -85,7 +85,7 @@
 	\brief Writes actual hyphen configuration into \a doc object.
 	\date
 	\author Franz Schmid
-	\param Wordlen lenght of the word.
+	\param Wordlen length of the word.
 	\param Autom is automatic flag.
 	\param ACheck AutoCheck flag.
 	\param Num HyCount

Modified: trunk/Scribus/scribus/observable.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/observable.h
==============================================================================
--- trunk/Scribus/scribus/observable.h	(original)
+++ trunk/Scribus/scribus/observable.h	Wed Feb 17 21:59:37 2016
@@ -81,7 +81,7 @@
 
 
 /**
-  Implement this interface if you want to observe an observable but dont want to derive from QObject 
+  Implement this interface if you want to observe an observable but don't want to derive from QObject 
  */
 template<class OBSERVED>
 class SCRIBUS_API Observer {
@@ -97,7 +97,7 @@
  An MassObservable is basically just the source of a changed() signal.
  Observers can register via the Qt signal/slot mechanism or via the above interface.
  
- The difference to Observable (below) is that a MassObservable doesnt report changes to
+ The difference to Observable (below) is that a MassObservable doesn't report changes to
  itself but to a bunch of SingleObservables.
  When you call update() on the SingleObservable, it will tell the associated
  MassObservable to notify all observers with the "changed" signal,

Modified: trunk/Scribus/scribus/pageitem.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/pageitem.h
==============================================================================
--- trunk/Scribus/scribus/pageitem.h	(original)
+++ trunk/Scribus/scribus/pageitem.h	Wed Feb 17 21:59:37 2016
@@ -1072,7 +1072,7 @@
 	bool textFlowUsesImageClipping() const { return (textFlowModeVal == TextFlowUsesImageClipping); }
 
 	/**
-	 * @brief To be called carefully because it eventually triggers a relayout of long text frames strings, but neccesarily when you change the document.
+	 * @brief To be called carefully because it eventually triggers a relayout of long text frames strings, but necessarily when you change the document.
 	 * @param allItems While you generally want to check for items below, it can happen that you want to update full range of text frames (e.g. when shuffle items order). Default to false.
 	 */
 	void checkTextFlowInteractions(bool allItems = false);

Modified: trunk/Scribus/scribus/pageitem_latexframe.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/pageitem_latexframe.h
==============================================================================
--- trunk/Scribus/scribus/pageitem_latexframe.h	(original)
+++ trunk/Scribus/scribus/pageitem_latexframe.h	Wed Feb 17 21:59:37 2016
@@ -38,7 +38,7 @@
 class QTimer;
 
 /** @brief Displays all kinds of content generated by external programs.
-	Named LatexFrame because it initally only showed the output of Latex.
+	Named LatexFrame because it initially only showed the output of Latex.
 */
 class SCRIBUS_API PageItem_LatexFrame : public PageItem_ImageFrame
 {

Modified: trunk/Scribus/scribus/pageitem_textframe.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/pageitem_textframe.cpp
==============================================================================
--- trunk/Scribus/scribus/pageitem_textframe.cpp	(original)
+++ trunk/Scribus/scribus/pageitem_textframe.cpp	Wed Feb 17 21:59:37 2016
@@ -2119,12 +2119,12 @@
 				//FIX ME - that should be paragraph style`s properties
 				//if set then indent is add to possible line start point (after overflow)
 				//if not then indent is calculated from column left edge
-				//if you dont agree that adding indent to overflow should be default behaviour
+				//if you don't agree that adding indent to overflow should be default behaviour
 				//then change it to false
 				bool addIndent2overflow = false; // should be addIndent2Overflow = style.addIndent2Overlow();
 				bool addFirstIndent2overflow = true; // should be addFirstIndent2Overflow = style.addFirstIndent2Overlow();
 				//if first line indent is negative and left indent should not be added to overflow
-				//then dont add first line ident either
+				//then don't add first line ident either
 				if ((style.firstIndent() < 0) && !addIndent2overflow)
 					addFirstIndent2overflow = false;
 
@@ -2272,7 +2272,7 @@
 					else /*if (current.startOfCol)*/
 					{
 						//FIX ME - that is ugly hack I must made, because simply expression
-						//current.yPos += diff; stop working, dont know why (compiler bug?)
+						//current.yPos += diff; stop working, don't know why (compiler bug?)
 						float YPOS = (float) current.yPos + (float) diff + 0.01;
 						current.yPos = (double) YPOS;
 						if (current.hasDropCap && diff > DropCapDrop)
@@ -2832,7 +2832,7 @@
 				// end of column
 				if (current.isEndOfCol(desc))
 				{
-					//check if realy line extends bottom margin
+					//check if really line extends bottom margin
 					current.updateHeightMetrics(itemText);
 					if (current.isEndOfCol(current.line.descent))
 					{
@@ -4986,7 +4986,7 @@
 		if (isNoteFrame()/* && findNotes*/)
 		{
 			//find and delete notes
-			//if marks are in notes then they will be deleted further while note is physicaly deleted
+			//if marks are in notes then they will be deleted further while note is physically deleted
 			for (int i=start; i < stop; ++i)
 			{
 				if (i == itemText.length())

Modified: trunk/Scribus/scribus/pdflib_core.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/pdflib_core.h
==============================================================================
--- trunk/Scribus/scribus/pdflib_core.h	(original)
+++ trunk/Scribus/scribus/pdflib_core.h	Wed Feb 17 21:59:37 2016
@@ -49,7 +49,7 @@
  * This is not public API and is not exported in Scribus's symbol table on supporting
  * platforms. Do not include this header, use pdflib.h instead. Including this header
  * from anywhere except pdflib.cpp may cause linker errors and other problems,
- * and is totally pointless since all the interfaces that are publically
+ * and is totally pointless since all the interfaces that are publicly
  * visible are presented by PDFlib anyway.
  *
  *@author Franz Schmid

Modified: trunk/Scribus/scribus/prefsmanager.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/prefsmanager.cpp
==============================================================================
--- trunk/Scribus/scribus/prefsmanager.cpp	(original)
+++ trunk/Scribus/scribus/prefsmanager.cpp	Wed Feb 17 21:59:37 2016
@@ -125,7 +125,7 @@
 	if (m_importingFrom12)
 		convert12Preferences();
 	//<<CB TODO Reset keyboard shortcuts of all 1.3 users as too many
-	//	 have conflicts if they dont nuke their settings.
+	//	 have conflicts if they don't nuke their settings.
 	// - Remove for 1.3.0 release: importingFrom12=true;
 	//>>CB
 }
@@ -814,7 +814,7 @@
 	bool retVal=false;
 	if (existsPrefs150[0] && existsPrefs150[2])
 		return retVal;
-	//Only check for these three as they will be autocreated if they dont exist.
+	//Only check for these three as they will be autocreated if they don't exist.
 	if( (existsPrefs135[0] && !existsPrefs140[0]) || (existsPrefs135[2] && !existsPrefs140[2]) )
 	{
 		// Now always return false
@@ -2298,7 +2298,7 @@
 			appPrefs.verifierPrefs.curCheckProfile = dc.attribute("CurrentProfile", CommonStrings::PostScript);
 			appPrefs.verifierPrefs.showPagesWithoutErrors = static_cast<bool>(dc.attribute("ShowPagesWithoutErrors", "0").toInt());
 			appPrefs.verifierPrefs.showNonPrintingLayerErrors = static_cast<bool>(dc.attribute("ShowNonPrintingLayerErrors", "0").toInt());
-			//#2516 work around old values until people wont have them anymore, not that these
+			//#2516 work around old values until people won't have them anymore, not that these
 			//translated strings should be going into prefs anyway!
 			if ((appPrefs.verifierPrefs.curCheckProfile == tr("PostScript")) ||
 				((appPrefs.verifierPrefs.curCheckProfile == tr("Postscript")) ||

Modified: trunk/Scribus/scribus/qtiocompressor.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/qtiocompressor.cpp
==============================================================================
--- trunk/Scribus/scribus/qtiocompressor.cpp	(original)
+++ trunk/Scribus/scribus/qtiocompressor.cpp	Wed Feb 17 21:59:37 2016
@@ -259,7 +259,7 @@
 {}
 
 /*!
-    Destroys the QtIOCompressor, closing it if neccesary.
+    Destroys the QtIOCompressor, closing it if necessary.
 */
 QtIOCompressor::~QtIOCompressor()
 {
@@ -319,7 +319,7 @@
     If the underlying device is not opened, this function will open it in a suitable mode. If this happens
     the device will also be closed when close() is called.
 
-    If the underlying device is already opened, its openmode must be compatable with \a mode.
+    If the underlying device is already opened, its openmode must be compatible with \a mode.
 
     Returns true on success, false on error.
 

Modified: trunk/Scribus/scribus/sampleitem.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/sampleitem.h
==============================================================================
--- trunk/Scribus/scribus/sampleitem.h	(original)
+++ trunk/Scribus/scribus/sampleitem.h	Wed Feb 17 21:59:37 2016
@@ -51,7 +51,7 @@
 		/*! \brief Set whole Scribus paragraph style in one.
 		\param aStyle Paragraph style to set.*/
 		void setStyle(const ParagraphStyle& aStyle);
-		/*! \brief Folowing methods set only one style characteristic */
+		/*! \brief Following methods set only one style characteristic */
 		void setLineSpaMode(int lineSpaMode);
 		void setLineSpa(double lineSpa);
 		void setTextAlignment(int textAlignment);

Modified: trunk/Scribus/scribus/scribus.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/scribus.cpp
==============================================================================
--- trunk/Scribus/scribus/scribus.cpp	(original)
+++ trunk/Scribus/scribus/scribus.cpp	Wed Feb 17 21:59:37 2016
@@ -1520,7 +1520,7 @@
 				else if (unicodevalue==SpecialChars::SHYPHEN.unicode()) //ignore the char as we use an attribute if the text item, for now.
 				{
 					// this code is currently dead since unicodeSoftHyphen
-					// doesnt have unicodevalue == -1 any more
+					// doesn't have unicodevalue == -1 any more
 					if (currItem->itemText.cursorPosition() > 1)
 					{
 #if 0
@@ -2556,7 +2556,7 @@
 	rebuildLayersList();
 	updateLayerMenu();
 	setLayerMenuText(doc->activeLayerName());
-	//Do not set this!, it doesnt get valid pointers unless its in EditClip mode and its not
+	//Do not set this!, it doesn't get valid pointers unless its in EditClip mode and its not
 	//if we are switching windows #4357
 	//nodePalette->setDoc(doc, view);
 	slotChangeUnit(doc->unitIndex(), false);
@@ -4226,7 +4226,7 @@
 	updateLayerMenu();
 	updateTableMenuActions();
 	rebuildScrapbookMenu();
-	//not running view's togglePreview as we dont want to affect the doc settings.
+	//not running view's togglePreview as we don't want to affect the doc settings.
 	scrActions["viewPreviewMode"]->setChecked(false);
 	appModeHelper->setPreviewMode(false);
 	return true;
@@ -8095,8 +8095,8 @@
 	PageItem *currItemSE = storyEditor->currentItem();
 	ScribusDoc *currDocSE = storyEditor->currentDocument();
 	storyEditor->activFromApp = true;
-	//CB shouldnt these be after the if?
-	//Why are we resetting the doc and item in this case. My original code didnt do this.
+	//CB shouldn't these be after the if?
+	//Why are we resetting the doc and item in this case. My original code didn't do this.
 	storyEditor->setCurrentDocumentAndItem(doc, i2);
 	if (i2 == currItemSE && doc == currDocSE)
 	{
@@ -8995,7 +8995,7 @@
 			doc->PageColors = dia->m_colorList;
 			if (dia->replaceColorMap.isEmpty())
 			{
-				// invalidate all charstyles, as replaceNamedResources() wont do it if all maps are empty
+				// invalidate all charstyles, as replaceNamedResources() won't do it if all maps are empty
 				const StyleSet<CharStyle> dummy;
 				doc->redefineCharStyles(dummy, false);
 			}

Modified: trunk/Scribus/scribus/scribus.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/scribus.h
==============================================================================
--- trunk/Scribus/scribus/scribus.h	(original)
+++ trunk/Scribus/scribus/scribus.h	Wed Feb 17 21:59:37 2016
@@ -559,7 +559,7 @@
 	void slotInsertMarkNote();
 	void slotInsertMarkIndex() { insertMark(MARKIndexType); }
 	void slotEditMark();
-	//connected to signal emited by actions when "Update Marks" menu item is triggered
+	//connected to signal emitted by actions when "Update Marks" menu item is triggered
 	void slotUpdateMarks();
 	bool editMarkDlg(Mark *mrk, PageItem_TextFrame* currItem = NULL);
 	void testQTQuick2_1();

Modified: trunk/Scribus/scribus/scribusdoc.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/scribusdoc.cpp
==============================================================================
--- trunk/Scribus/scribus/scribusdoc.cpp	(original)
+++ trunk/Scribus/scribus/scribusdoc.cpp	Wed Feb 17 21:59:37 2016
@@ -7171,7 +7171,7 @@
 		destination->setOrientation(from->orientation());
 		destination->m_pageSize = from->m_pageSize;
 		//CB: Can possibly partially use the code from applyMasterPage here instead of runnin all of this again..
-		//TODO make a fucntion to do this margin stuff and use elsewhere too
+		//TODO make a function to do this margin stuff and use elsewhere too
 		destination->initialMargins.setTop(from->initialMargins.top());
 		destination->initialMargins.setBottom(from->initialMargins.bottom());
 		if (pageSets()[m_docPrefsData.docSetupPrefs.pagePositioning].Columns == 1)
@@ -15483,7 +15483,7 @@
 	uint selectedItemCount=itemSelection->count();
 	if (selectedItemCount == 0)
 		return;
-	//Create our copy selection as our item *s will be invalidated as we go through the loop and the selection index wont work
+	//Create our copy selection as our item *s will be invalidated as we go through the loop and the selection index won't work
 	//convertItemTo does this
 	Selection tmpSel(*itemSelection);
 	tmpSel.disconnectAllItemsFromGUI();
@@ -16656,7 +16656,7 @@
 							else if (style.numOther())
 							{
 								ParagraphStyle preStyle = item->itemText.paragraphStyle(pos -1);
-								//reset counter if prev style hasnt numeration or has other numeration
+								//reset counter if prev style hasn't numeration or has other numeration
 								if (!preStyle.hasNum() || (preStyle.numName() != style.numName()))
 									resetNums = true;
 							}
@@ -17309,7 +17309,7 @@
 void ScribusDoc::updateItemNotesNums(PageItem_TextFrame* frame, NotesStyle* nStyle, int &num)
 {
 	//update marks strings in master text and in notes frame (only numbers!)
-	//check if notes schould be added or removed from notes frame
+	//check if notes should be added or removed from notes frame
 	int noteNum = num;
 	int index = 0;
 	bool doUpdate = false;
@@ -17987,7 +17987,7 @@
 
 bool ScribusDoc::validateNSet(NotesStyle NS, QString newName)
 {
-	//check if choosen numbering type is avaiable with choosen range, prefix and suffix
+	//check if chosen numbering type is available with chosen range, prefix and suffix
 	QString errStr;
 	foreach (NotesStyle* NS2, m_docNotesStylesList)
 	{

Modified: trunk/Scribus/scribus/scribusdoc.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/scribusdoc.h
==============================================================================
--- trunk/Scribus/scribus/scribusdoc.h	(original)
+++ trunk/Scribus/scribus/scribusdoc.h	Wed Feb 17 21:59:37 2016
@@ -1652,7 +1652,7 @@
 	 * Explanation
 	 * master frame - text frame with marks for notes
 	 * notesframe - frame with notes
-	 * master & note mark - master is mark in "master" text, note mark is at begining of note in noteframe
+	 * master & note mark - master is mark in "master" text, note mark is at beginning of note in noteframe
 	 */
 	
 	//return page where endnotesframe should be located depending of notes style range and location of master mark
@@ -1698,7 +1698,7 @@
 	bool eraseMark(Mark* mrk, bool fromText=false, PageItem* item=NULL, bool force = false); //force is used only for deleting non-unique marks by MarksManager
 	void setUndoDelMark(Mark* mrk);
 	//invalidate all text frames where given mark will found
-	//usefull spacially for varaible text marks after changing its text definition
+	//useful spacially for varaible text marks after changing its text definition
 	//if forceUpdate then found master frames are relayouted
 	bool invalidateVariableTextFrames(Mark* mrk, bool forceUpdate = false); //returns if any text was changed
 

Modified: trunk/Scribus/scribus/selection.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/selection.h
==============================================================================
--- trunk/Scribus/scribus/selection.h	(original)
+++ trunk/Scribus/scribus/selection.h	Wed Feb 17 21:59:37 2016
@@ -74,7 +74,7 @@
 		 * @brief Add an item to the selection. 
 		 * If its added to a GUI selection selection and its item 0, its connected to the GUI too
 		 * @param item Item to add
-		 * @param ignoreGUI Dont connect Item To GUI even if this is a GUI selection
+		 * @param ignoreGUI Don't connect Item To GUI even if this is a GUI selection
 		 * @return If the item was added
 		 */
 		bool addItem(PageItem *item, bool ignoreGUI=false);

Modified: trunk/Scribus/scribus/tableborder.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/tableborder.h
==============================================================================
--- trunk/Scribus/scribus/tableborder.h	(original)
+++ trunk/Scribus/scribus/tableborder.h	Wed Feb 17 21:59:37 2016
@@ -73,7 +73,7 @@
 	Qt::PenStyle m_style;
 	/// The color of the table border line.
 	QString m_color;
-	/// Ths shade of the table border line
+	/// The shade of the table border line
 	double m_shade;
 };
 Q_DECLARE_TYPEINFO(TableBorderLine, Q_MOVABLE_TYPE);

Modified: trunk/Scribus/scribus/tocgenerator.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/tocgenerator.cpp
==============================================================================
--- trunk/Scribus/scribus/tocgenerator.cpp	(original)
+++ trunk/Scribus/scribus/tocgenerator.cpp	Wed Feb 17 21:59:37 2016
@@ -90,7 +90,7 @@
 			//Item not on a page, continue
 			if (currentDocItem->OwnPage == -1)
 				continue;
-			//If we dont want to list non printing frames and this one is set to not print, continue
+			//If we don't want to list non printing frames and this one is set to not print, continue
 			if (!tocSetupIt->listNonPrintingFrames && !currentDocItem->printEnabled())
 				continue;
 

Modified: trunk/Scribus/scribus/transaction.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/transaction.h
==============================================================================
--- trunk/Scribus/scribus/transaction.h	(original)
+++ trunk/Scribus/scribus/transaction.h	Wed Feb 17 21:59:37 2016
@@ -63,7 +63,7 @@
 	
 	/**
 		Automatically commits if forgotten.
-		Override as appropiate. Since the superclass destructor is called last, you
+		Override as appropriate. Since the superclass destructor is called last, you
 	    can cancel in the subclass destructor; the commit here then will do nothing.
 	    Don't forget to set m_data to NULL if you free the m_data pointer!
 	 */

Modified: trunk/Scribus/scribus/ui/aboutplugins.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/aboutplugins.cpp
==============================================================================
--- trunk/Scribus/scribus/ui/aboutplugins.cpp	(original)
+++ trunk/Scribus/scribus/ui/aboutplugins.cpp	Wed Feb 17 21:59:37 2016
@@ -69,7 +69,7 @@
 	html += "<table>";
 	html += QString("<tr><th>%1</th><td>%2</td></tr>").arg( tr("Filename:")).arg(fi.completeBaseName());
 	html += QString("<tr><th>%1</th><td>%2</td></tr>").arg( tr("Version:")).arg(about->version);
-// As we dont allow users to disable plugins, hide this
+// As we don't allow users to disable plugins, hide this
 //	QString ena;
 //	ena = pluginManager.enabled(name) ? CommonStrings::trYes : CommonStrings::trNo;
 //	html += QString("<tr><th>%1</th><td>%2</td></tr>").arg( tr("Enabled:")).arg(ena);

Modified: trunk/Scribus/scribus/ui/helpbrowser.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/helpbrowser.cpp
==============================================================================
--- trunk/Scribus/scribus/ui/helpbrowser.cpp	(original)
+++ trunk/Scribus/scribus/ui/helpbrowser.cpp	Wed Feb 17 21:59:37 2016
@@ -564,7 +564,7 @@
 		{
 			if (!language.isEmpty())
 			{
-				//Check if we can load, eg "de" when "de_CH" docs dont exist
+				//Check if we can load, eg "de" when "de_CH" docs don't exist
 				QString baseHelpMenuFile3 = QDir::toNativeSeparators(baseHelpDir + language.left(2) + "/menu.xml");
 				QString altHelpMenuFile3 = QDir::toNativeSeparators(altHelpDir + "doc/" + language.left(2) + "/menu.xml");
 				QFileInfo fi3 = QFileInfo(baseHelpMenuFile3);

Modified: trunk/Scribus/scribus/ui/helpbrowser.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/helpbrowser.h
==============================================================================
--- trunk/Scribus/scribus/ui/helpbrowser.h	(original)
+++ trunk/Scribus/scribus/ui/helpbrowser.h	Wed Feb 17 21:59:37 2016
@@ -162,11 +162,11 @@
 	\author Petr Vanek <petr at yarpen.cz> */
 	void find();
 
-	/*! \brief Find next occurences of the text in one document.
+	/*! \brief Find next occurrences of the text in one document.
 	\author Petr Vanek <petr at yarpen.cz> */
 	void findNext();
 
-	/*! \brief Find previous occurences of the text in one document.
+	/*! \brief Find previous occurrences of the text in one document.
 	\author Petr Vanek <petr at yarpen.cz> */
 	void findPrevious();
 

Modified: trunk/Scribus/scribus/ui/pageitemattributes.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/pageitemattributes.cpp
==============================================================================
--- trunk/Scribus/scribus/ui/pageitemattributes.cpp	(original)
+++ trunk/Scribus/scribus/ui/pageitemattributes.cpp	Wed Feb 17 21:59:37 2016
@@ -239,7 +239,7 @@
 
 void PageItemAttributes::okClicked()
 {
-	//Qt hack as we will lose data if the user hasnt left a cell
+	//Qt hack as we will lose data if the user hasn't left a cell
 	//http://www.qtforum.org/thread.php?threadid=9078
 	if (attributesTable->rowCount()>0 && attributesTable->currentRow()!=-1)
 	{

Modified: trunk/Scribus/scribus/ui/pageitemsetterbase.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/pageitemsetterbase.h
==============================================================================
--- trunk/Scribus/scribus/ui/pageitemsetterbase.h	(original)
+++ trunk/Scribus/scribus/ui/pageitemsetterbase.h	Wed Feb 17 21:59:37 2016
@@ -35,7 +35,7 @@
 *  properties of a page item.
 *
 * note about dragging:
-* this base class is expected to handle propper dragging, droppers
+* this base class is expected to handle proper dragging, droppers
 * must ask the pageitemsettersmanager a clone of a dropped setter based
 * on the name.
 *

Modified: trunk/Scribus/scribus/ui/printdialog.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/printdialog.cpp
==============================================================================
--- trunk/Scribus/scribus/ui/printdialog.cpp	(original)
+++ trunk/Scribus/scribus/ui/printdialog.cpp	Wed Feb 17 21:59:37 2016
@@ -175,7 +175,7 @@
 	{
 		delete cdia; // if options was canceled delete dia 
 		cdia = 0;    // so that getoptions() in the okButtonClicked() will get 
-		             // the default values from the last succesful run
+		             // the default values from the last successful run
 	}
 
 #elif defined(_WIN32)

Modified: trunk/Scribus/scribus/ui/propertiespalette.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/propertiespalette.cpp
==============================================================================
--- trunk/Scribus/scribus/ui/propertiespalette.cpp	(original)
+++ trunk/Scribus/scribus/ui/propertiespalette.cpp	Wed Feb 17 21:59:37 2016
@@ -368,10 +368,10 @@
 {
 	if (!m_ScMW || m_ScMW->scriptIsRunning())
 		return;
-	//CB We shouldnt really need to process this if our item is the same one
+	//CB We shouldn't really need to process this if our item is the same one
 	//maybe we do if the item has been changed by scripter.. but that should probably
 	//set some status if so.
-	//FIXME: This wont work until when a canvas deselect happens, m_item must be NULL.
+	//FIXME: This won't work until when a canvas deselect happens, m_item must be NULL.
 	//if (m_item == i)
 	//	return;
 

Modified: trunk/Scribus/scribus/ui/resourcemanager.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/resourcemanager.cpp
==============================================================================
--- trunk/Scribus/scribus/ui/resourcemanager.cpp	(original)
+++ trunk/Scribus/scribus/ui/resourcemanager.cpp	Wed Feb 17 21:59:37 2016
@@ -630,12 +630,12 @@
 					QFile dledFile(fn);
 					QFileInfo fi(dledFile);
 					if (!dledFile.exists())
-						qDebug()<<"File doesnt exist"<<fn;
+						qDebug()<<"File doesn\'t exist"<<fn;
 					else
 					{
 						ScZipHandler* fun = new ScZipHandler();
 						if (!fun->open(fn))
-							qDebug()<<"Zip file doesnt open"<<fn;
+							qDebug()<<"Zip file doesn\'t open"<<fn;
 						else
 						{
 							QStringList zipFileContents(fun->files());
@@ -672,12 +672,12 @@
 					QFile dledFile(fn);
 					QFileInfo fi(dledFile);
 					if (!dledFile.exists())
-						qDebug()<<"File doesnt exist"<<fn;
+						qDebug()<<"File doesn\'t exist"<<fn;
 					else
 					{
 						ScZipHandler* fun = new ScZipHandler();
 						if (!fun->open(fn))
-							qDebug()<<"Zip file doesnt open"<<fn;
+							qDebug()<<"Zip file doesn\'t open"<<fn;
 						else
 						{
 							QStringList zipContents(fun->files());

Modified: trunk/Scribus/scribus/ui/scrpalettebase.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/scrpalettebase.h
==============================================================================
--- trunk/Scribus/scribus/ui/scrpalettebase.h	(original)
+++ trunk/Scribus/scribus/ui/scrpalettebase.h	Wed Feb 17 21:59:37 2016
@@ -54,7 +54,7 @@
 		int exec(QWidget* newParent);
 		
 	signals:
-		/** @brief Let the action for this palette know when something changes and it hasnt caused it */
+		/** @brief Let the action for this palette know when something changes and it hasn't caused it */
 		void paletteShown(bool);
 		
 	protected:

Modified: trunk/Scribus/scribus/ui/scrspinbox.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/scrspinbox.cpp
==============================================================================
--- trunk/Scribus/scribus/ui/scrspinbox.cpp	(original)
+++ trunk/Scribus/scribus/ui/scrspinbox.cpp	Wed Feb 17 21:59:37 2016
@@ -364,7 +364,7 @@
 	*/
 	if ( event->type() == QEvent::Wheel )
 	{
-		//If read only dont spin
+		//If read only don't spin
 		if (isReadOnly())
 			return false;
 		QWheelEvent* k = (QWheelEvent*)event;

Modified: trunk/Scribus/scribus/ui/smlinestyle.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/smlinestyle.cpp
==============================================================================
--- trunk/Scribus/scribus/ui/smlinestyle.cpp	(original)
+++ trunk/Scribus/scribus/ui/smlinestyle.cpp	Wed Feb 17 21:59:37 2016
@@ -281,7 +281,7 @@
 
 void SMLineStyle::setDefaultStyle(bool ids)
 {
-	/* we dont have default line styles yet
+	/* we don't have default line styles yet
 	Q_ASSERT(m_selection.count() == 1);
 	if (m_selection.count() != 1)
 		return;

Modified: trunk/Scribus/scribus/ui/storyeditor.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/storyeditor.cpp
==============================================================================
--- trunk/Scribus/scribus/ui/storyeditor.cpp	(original)
+++ trunk/Scribus/scribus/ui/storyeditor.cpp	Wed Feb 17 21:59:37 2016
@@ -1846,7 +1846,7 @@
 	m_smartSelection = prefsManager->appPrefs.storyEditorPrefs.smartTextSelection;
 	initActions();
 	ActionManager::initUnicodeActions(&seActions, this, &unicodeCharActionNames);
-	seActions["unicodeSoftHyphen"]->setEnabled(false);//CB TODO doesnt work in SE yet.
+	seActions["unicodeSoftHyphen"]->setEnabled(false);//CB TODO doesn't work in SE yet.
 	buildMenus();
 
 	setWindowIcon(IconManager::instance()->loadPixmap("AppIcon.png"));
@@ -2239,7 +2239,7 @@
 				activFromApp = true;
 				if (m_item != NULL)
 				{
-					//set to false otherwise some dialog properties wont be set correctly
+					//set to false otherwise some dialog properties won't be set correctly
 					if (m_item->itemText.length() == 0)
 						m_firstSet = false; 
 					disconnectSignals();
@@ -2914,7 +2914,7 @@
 
 void StoryEditor::updateTextFrame()
 {
-	//Return immediately if we dont have to update the frame
+	//Return immediately if we don't have to update the frame
 	if (!m_textChanged)
 		return;
 	PageItem *nextItem = m_item;

Modified: trunk/Scribus/scribus/ui/stylemanager.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/stylemanager.cpp
==============================================================================
--- trunk/Scribus/scribus/ui/stylemanager.cpp	(original)
+++ trunk/Scribus/scribus/ui/stylemanager.cpp	Wed Feb 17 21:59:37 2016
@@ -589,7 +589,7 @@
 
 void StyleManager::slotNew()
 {
-//#5334: Dont open into edit mdoe until user has selected a style type
+//#5334: Don't open into edit mdoe until user has selected a style type
 // 	if (!m_isEditMode)
 // 		slotOk(); // switch to edit mode for a new style
 
@@ -897,7 +897,7 @@
 			else 
 			{
 				bool postpone = false;
-				// search if parent is in remaing styles
+				// search if parent is in remaining styles
 				for (int j = i+1; j < styles.count(); ++j)
 				{
 					if (styles[j].first == styles[i].second)

Modified: trunk/Scribus/scribus/ui/tabruler.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/tabruler.h
==============================================================================
--- trunk/Scribus/scribus/ui/tabruler.h	(original)
+++ trunk/Scribus/scribus/ui/tabruler.h	Wed Feb 17 21:59:37 2016
@@ -127,7 +127,7 @@
 	void setCustomFillChar(const QString &txt);
 
 signals:
-	/*! This signal is emited when is something changed in the tab ruler dialog/widget.
+	/*! This signal is emitted when something is changed in the tab ruler dialog/widget.
 	4/11/2005 pv */
 	void tabrulerChanged();
 

Modified: trunk/Scribus/scribus/ui/unicodesearch.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/ui/unicodesearch.h
==============================================================================
--- trunk/Scribus/scribus/ui/unicodesearch.h	(original)
+++ trunk/Scribus/scribus/ui/unicodesearch.h	Wed Feb 17 21:59:37 2016
@@ -124,7 +124,7 @@
 	virtual void changeEvent(QEvent *e);
 
 signals:
-	//! \brief Signal transfering the chosen character as QString
+	//! \brief Signal transferring the chosen character as QString
 	void chosenUnicode(const QString &);
 
 public slots:

Modified: trunk/Scribus/scribus/undogui.h
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/undogui.h
==============================================================================
--- trunk/Scribus/scribus/undogui.h	(original)
+++ trunk/Scribus/scribus/undogui.h	Wed Feb 17 21:59:37 2016
@@ -406,7 +406,7 @@
 	/** @brief Remove the last (oldest) item from the undo stack representation. */
 	void popBack();
 
-	/** @brief Recieve prefsChanged() signal to update shortcuts. */
+	/** @brief Receive prefsChanged() signal to update shortcuts. */
 	void updateFromPrefs();
 
 signals:

Modified: trunk/Scribus/scribus/units.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/units.cpp
==============================================================================
--- trunk/Scribus/scribus/util_printer.cpp	(original)
+++ trunk/Scribus/scribus/util_printer.cpp	Wed Feb 17 21:59:37 2016
@@ -145,7 +145,7 @@
 		ppd = ppdOpenFile(filename);
 		if (ppd!=NULL)
 		{
-			ppd_size_t *size; // page size data, null if printer doesnt support selected size
+			ppd_size_t *size; // page size data, null if printer doesn't support selected size
 			size = ppdPageSize(ppd, pageSize.toLocal8Bit().constData());
 			if (size!=NULL)
 			{




More information about the scribus-commit mailing list
--- trunk/Scribus/scribus/units.cpp	(original)
+++ trunk/Scribus/scribus/units.cpp	Wed Feb 17 21:59:37 2016
@@ -30,7 +30,7 @@
 double unitGetRatioFromIndex(const int index)
 {
 	//PT, MM, IN, P, CM, C (Cicero)
-	//NOTE: Calling functions that divide by this value will crash on divide by 0. They shouldnt be getting
+	//NOTE: Calling functions that divide by this value will crash on divide by 0. They shouldn't be getting
 	// a zero value if they are accessing here with a correct index.
 	if (index<UNITMIN || index>UNITMAX)
 		return 0;
@@ -211,7 +211,7 @@
 	suffixList.append( QObject::tr( "Picas (p)" ) );
 	suffixList.append( QObject::tr( "Centimeters (cm)" ) );
 	suffixList.append( QObject::tr( "Cicero (c)" ) );
 	//Here for completeness, dont use!
 	//suffixList.append( QObject::tr( "°" ) );
 	//suffixList.append( QObject::tr( "%" ) );
 	return QStringList(suffixList);
@@ -317,7 +317,7 @@
 		case 3:
 		case 6:
 		case 7:
-			ret = unitValue; //dont multiply by 1
+			ret = unitValue; //don't multiply by 1
 			break;
 		default:
 			ret = unitValue * unitGetRatioFromIndex(unit);
@@ -338,7 +338,7 @@
 		case 3:
 		case 6:
 		case 7:
-			ret = unitValue; // dont divide by 1
+			ret = unitValue; // don't divide by 1
 			break;
 		default:
 			ret = unitValue / unitGetRatioFromIndex(unit);
@@ -211,7 +211,7 @@
 	suffixList.append( QObject::tr( "Centimeters (cm)" ) );
 	suffixList.append( QObject::tr( "Cicero (c)" ) );
-	//Here for completeness, dont use!
+	//Here for completeness, don't use!
 	//suffixList.append( QObject::tr( "°" ) );
 	//suffixList.append( QObject::tr( "%" ) );

Modified: trunk/Scribus/scribus/util_printer.cpp
URL: http://scribus.net/websvn/diff.php?repname=Scribus&rev=21017&path=/trunk/Scribus/scribus/util_printer.cpp
==============================================================================